#
# spec file for package qtkeychain-qt6
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 1
Name:           qtkeychain-qt6
Version:        0.14.2
Release:        1.2
Summary:        Platform-independent Qt API for storing passwords securely
License:        BSD-2-Clause
URL:            https://github.com/frankosterfeld/qtkeychain
Source:         https://github.com/frankosterfeld/qtkeychain/archive/refs/tags/%{version}.tar.gz#/qtkeychain-qt5-%{version}.tar.gz
BuildRequires:  pkgconfig
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6DBus)
BuildRequires:  cmake(Qt6LinguistTools)
BuildRequires:  pkgconfig(libsecret-1)

%description
QtKeychain is a Qt API to store passwords and other secret data securely.

%package -n libqt6keychain%{sover}
Summary:        Qt 6 keychain library
Recommends:     qtkeychain-qt6-lang

%description -n libqt6keychain%{sover}
The Qt 6 keychain library.

%package devel
Summary:        Development files for libqt6keychain
Requires:       libqt6keychain%{sover} = %{version}
Requires:       cmake(Qt6Core)
Requires:       cmake(Qt6DBus)

%description devel
This package contains development files for using the Qt6 keychain API.

%package lang
Summary:        Translations for package %{name}
Requires:       libqt6keychain%{sover} = %{version}
Provides:       %{name}-lang-all = %{version}
BuildArch:      noarch

%description lang
Provides translations for the "qtkeychain-qt6" package.

%prep
%autosetup -p1 -n qtkeychain-%{version}

%build
%cmake_qt6 \
  -DBUILD_WITH_QT6=ON \
  -DQMAKE_EXECUTABLE=%{_qt6_bindir}/qmake

%qt6_build

%install
%qt6_install

%find_lang qtkeychain --with-qt

%ldconfig_scriptlets -n libqt6keychain%{sover}

%files -n libqt6keychain%{sover}
%license COPYING
%doc ChangeLog ReadMe.md
%{_libdir}/libqt6keychain.so.%{sover}
%{_libdir}/libqt6keychain.so.%{version}

%files devel
%{_includedir}/qt6keychain
%{_libdir}/libqt6keychain.so
%{_libdir}/cmake/Qt6Keychain/
%{_qt6_mkspecsdir}/modules/qt_Qt6Keychain.pri

%files lang -f qtkeychain.lang
%dir %{_datadir}/qt6keychain
%dir %{_datadir}/qt6keychain/translations

%changelog
* Mon Mar 11 2024 Christophe Marin <christophe@krop.fr>
- Update to 0.14.2
  * Add support for KWallet 6
* Wed Aug  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 0.14.1:
  * Many build system fixes and build fixes for recent Qt 6
    releases
  * Add QtQuick client example
  * Added Dutch translation
  * Add API to check whether a secure backend is available
    at all
  * Export QKeychain::isAvailable() to make it usable in a
    shared build
  * Protect against creating the QtKeychain::QtKeychain alias
    target twice
- Drop patch, merged upstream:
  * 0001-Define-a-poper-exported-CMake-target-instead-of-intr.patch
- Add missing dependency to the -devel packages
* Thu May  4 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add _multibuild to define 2nd spec file as additional flavor.
  Eliminates the need for source package links in OBS.
* Sat Feb  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Use the qt6 macros to build qtkeychain-qt6
* Wed Feb  2 2022 Christophe Giboudeaux <christophe@krop.fr>
- Add patch to restore compatibility with CMake 3.16:
  * 0001-Define-a-poper-exported-CMake-target-instead-of-intr.patch
* Tue Dec 14 2021 Christophe Giboudeaux <christophe@krop.fr>
- Fix qtkeychain users on Leap.
* Fri Dec 10 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 0.13.2
  * Linux: Require libsecret if not explicitly disabled
  * Unify implementations for macOS and iOS
  * CMake: lots of fixes
  * KWallet: Fix deletion of entries
  * CMake: Deprecate QTKEYCHAIN_STATIC in favor of
    BUILD_SHARED_LIBS
- Drop the unneeded baselibs.conf.
* Sat Jan  9 2021 Fabian Vogt <fabian@ritter-vogt.de>
- %%lang_package doesn't handle -r and -n parameters at the same
  time, expand it manually
* Wed Dec 30 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add qtkeychain-qt6.
- Add the missing libsecret build dependency to qtkeychain-qt5.
* Tue Dec 29 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Use %%find_lang
* Tue Dec 29 2020 Dirk Müller <dmueller@suse.com>
- update to 0.12.0:
  * Add Qt 6 support, drop Qt 4 support
  * Require C++11
  * Add Android support (Mathias Hasselmann)
  * Build system fixes
* Wed Feb 26 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 0.10.0:
  * Detect XFCE desktop correctly
  * Fix build with Qt 5.12.x
  * translations update
- Drop upstream patches:
  * 0001-On-Unix-systems-shared-libraries-have-a-abi-version.patch
  * 0002-Detect-XFCE-desktop-correctly.patch
  * 0003-Generate-Qt-5.12.1-compatible-qt_Qt5Keychain.pri.patch
* Mon Jun 17 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Add fixes from git master:
  * 0001-On-Unix-systems-shared-libraries-have-a-abi-version.patch
  * 0002-Detect-XFCE-desktop-correctly.patch
  * 0003-Generate-Qt-5.12.1-compatible-qt_Qt5Keychain.pri.patch (boo#1130608)
* Mon Oct 22 2018 Jan Engelhardt <jengelh@inai.de>
- Trim fill words from description. Ensure neutrality of it, too.
* Mon Oct 22 2018 Christophe Giboudeaux <christophe@krop.fr>
- Update to 0.9.1. Changes since 0.8.0:
  * Only require QtLinguist if building translations
  * Fall back on libsecret if kwallet is not available
  * Secret: Don't match the schema name
* Sat May 26 2018 christophe@krop.fr
- Update to 0.8.0:
  * Buildsystem improvements.
  * Enable C++11 support for Qt >= 5.7.
  * Doxygen documentation.
  * Libsecret support.
* Tue Jul 12 2016 hrvoje.senjan@gmail.com
- Update to 0.7.0
  * Bump SO version due to 0.6 being binary-incompatible
    qto previous releases
- Changes since 0.6.2
  * KWallet: Fixes a crash when storing passwords, seen on Debian/KDE4
- Changes since 0.6.1
  * Fix KWallet not working (regressions in 0.6.0)
- Changes since 0.6.0
  * Added support for the Windows Credential Store
* Tue Feb  9 2016 cgiboudeaux@gmx.com
- Update to 0.5.0
  Added support for KWallet5
* Wed Oct 22 2014 hrvoje.senjan@gmail.com
- Activate qtkeychain-qt5 package
